Files bundle
------------

The files bundle contains all modules related to files management,
an object storage REST API, storage backends, file previewers,
IIIF image APIs and an integration layer between files and records.

Included modules:

- `invenio-files-rest <https://invenio-files-rest.readthedocs.io>`_
    - Object storage REST API for Invenio with many supported backend storage
      protocols and file integrity checking.
- `invenio-iiif <https://invenio-iiif.readthedocs.io>`_
    - International Image Interoperability Framework (IIIF) server for making
      thumbnails and zooming images.
- `invenio-previewer <https://invenio-previewer.readthedocs.io>`_
    - Previewer for Markdown, JSON/XML, CSV, PDF, JPEG, PNG, TIFF, GIF and ZIP
      files.
- `invenio-records-files <https://invenio-records-files.readthedocs.io>`_
    - Integration layer between object storage and records.
